courts.tjpi.client.TJPIScraper

courts.tjpi.client.TJPIScraper()

Scraper for the Tribunal de Justica do Piaui (TJPI).

Uses the JusPI search interface at jurisprudencia.tjpi.jus.br. Results are HTML-based (server-rendered) and parsed with BeautifulSoup.

Methods

Name Description
cjsg Search TJPI jurisprudence.
cjsg_download Download raw HTML pages from TJPI.
cjsg_parse Parse downloaded HTML pages.
cpopg Stub: first instance case consultation not implemented for TJPI.
cposg Stub: second instance case consultation not implemented for TJPI.

cjsg

courts.tjpi.client.TJPIScraper.cjsg(
    pesquisa=None,
    paginas=None,
    tipo='',
    relator='',
    classe='',
    orgao='',
    **kwargs,
)

Search TJPI jurisprudence.

Parameters

pesquisa : str Free-text search term. paginas : int, list, range, or None Pages to download (1-based). None downloads all. tipo : str, optional Decision type. Options: "Acordao", "Decisao Terminativa", "Sumula". relator : str, optional Reporter judge name (must match dropdown value exactly). classe : str, optional Procedural class (must match dropdown value exactly). orgao : str, optional Judging body (must match dropdown value exactly).

Returns

pd.DataFrame

cjsg_download

courts.tjpi.client.TJPIScraper.cjsg_download(
    pesquisa=None,
    paginas=None,
    **kwargs,
)

Download raw HTML pages from TJPI.

Returns

list List of raw HTML strings (one per page).

cjsg_parse

courts.tjpi.client.TJPIScraper.cjsg_parse(resultados_brutos)

Parse downloaded HTML pages.

Returns

pd.DataFrame

cpopg

courts.tjpi.client.TJPIScraper.cpopg(id_cnj)

Stub: first instance case consultation not implemented for TJPI.

cposg

courts.tjpi.client.TJPIScraper.cposg(id_cnj)

Stub: second instance case consultation not implemented for TJPI.